==> jc-1.4.0.tar.gz: soot/jimple/toolkits/annotation/arraycheck/BoundedPriorityList.h <==
// class soot.jimple.toolkits.annotation.arraycheck.BoundedPriorityList

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 702ac10d9f00432b soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList_H_
#define _JC_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_LinkedList$object;
struct _jc_java_util_List$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$sub_refs	_jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$sub_refs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$sub_nonrefs	_jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$refs	_jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$refs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$nonrefs	_jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$object	_jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$object;

typedef const struct _jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$vmethods	_jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$vmethods;
typedef const struct _jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$vtable	_jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$vtable;
typedef const struct _jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$vtype	_jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$method$_init$dd8ff073a2c7f994(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$object *, struct _jc_object *);

// Virtual methods
extern void _jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$method$add$75d6bd5079bf5583(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$object *, struct _jc_java_lang_Object$object *);
extern jboolean _jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$method$isEmpty$551bea84f4e0f0cb(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$method$removeFirst$539049aa2de97f0d(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$method_info$add$75d6bd5079bf5583;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$method_info$isEmpty$551bea84f4e0f0cb;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$method_info$removeFirst$539049aa2de97f0d;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$vmethods {
	void	(*add$75d6bd5079bf5583)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$object *, struct _jc_java_lang_Object$object *);
	jboolean	(*isEmpty$551bea84f4e0f0cb)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$object *);
	struct _jc_java_lang_Object$object	*(*removeFirst$539049aa2de97f0d)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$object *);
};

// Vtable
struct _jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$vmethods	soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList;
};

// Vtype
struct _jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$sub_refs {
	struct _jc_object	*fulllist;
	struct _jc_java_util_LinkedList$object	*worklist;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$refs {
    _jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$sub_refs	soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$sub_nonrefs	soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$object {
	_jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$vtype	*vtype;
	_jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$vtype _jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$class_object;

#endif	/* _JC_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/annotation/arraycheck/BoundedPriorityList.h <==
// class soot.jimple.toolkits.annotation.arraycheck.BoundedPriorityList

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 702ac10d9f00432b soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList_H_
#define _JC_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_LinkedList$object;
struct _jc_java_util_List$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$sub_refs	_jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$sub_refs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$sub_nonrefs	_jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$refs	_jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$refs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$nonrefs	_jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$object	_jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$object;

typedef const struct _jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$vmethods	_jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$vmethods;
typedef const struct _jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$vtable	_jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$vtable;
typedef const struct _jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$vtype	_jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$method$_init$dd8ff073a2c7f994(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$method$add$75d6bd5079bf5583(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$method$isEmpty$551bea84f4e0f0cb(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$method$removeFirst$539049aa2de97f0d(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$method_info$add$75d6bd5079bf5583;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$method_info$isEmpty$551bea84f4e0f0cb;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$method_info$removeFirst$539049aa2de97f0d;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$vmethods {
	void	(*add$75d6bd5079bf5583)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	jboolean	(*isEmpty$551bea84f4e0f0cb)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*removeFirst$539049aa2de97f0d)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$vmethods	soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList;
};

// Vtype
struct _jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$sub_refs {
	struct _jc_object	*fulllist;
	struct _jc_java_util_LinkedList$object	*worklist;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$refs {
    _jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$sub_refs	soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$sub_nonrefs	soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$object {
	_jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$vtype	*vtype;
	_jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$vtype _jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList$class_object;

#endif	/* _JC_soot_jimple_toolkits_annotation_arraycheck_BoundedPriorityList_H_ */
